style "panel"
{
	xthickness = 0
	ythickness = 0

	bg[NORMAL] = "#d8d8d8"
  engine "clearlooks"
  {

}
}

class "*Panel*Applet*" style "panel"
widget "*PanelWidget*" style "panel"
widget "*PanelApplet*" style "panel"
class "*Panel*" style "panel"


style "panel-menubar"
{

engine "pixmap"
	{
	image
	{
		function	= BOX
		state		= NORMAL
		file		= "panel/panel-bgb.png"
		border		= { 7 , 7 , 7 , 7}
		stretch		= TRUE
	}
	image
	{
		function	= BOX
		state		= ACTIVE
		file		= "panel/panel-bgb.png"
		border		= { 7 , 7 , 7 , 7}
		stretch		= TRUE
	}
	image
	{
		function	= BOX
		state		= INSENSITIVE
		file		= "panel/panel-bgb.png"
		border		= { 7 , 7 , 7 , 7}
		stretch		= TRUE
	}
}
}
widget_class "*Panel*MenuBar*" style "panel-menubar"

