style "scrollbar" = "default"
{
	GtkRange::trough-border = 0
	GtkRange::slider-width = 15
	GtkRange::stepper-size = 15

  engine "pixmap" 
  {

    image 
    {
      function			= BOX
      recolorable		= TRUE
      detail			= "trough"
      file				= "Scrollbars/trough-scrollbar-horiz.png"
      border			= { 20, 20, 5, 5 }
      stretch			= TRUE
      orientation		= HORIZONTAL
    }
    image 
    {
      function			= BOX
      recolorable		= TRUE
      detail			= "trough"
      file				= "Scrollbars/trough-scrollbar-vert.png"
      border			= { 5, 5, 20, 20 }
      stretch			= TRUE
      orientation		= VERTICAL
    }


###########x SLIDERS ##################x

  image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= NORMAL
      file				= "Scrollbars/slider-horiz.png" 
      border			= { 5, 5, 3, 3}
      stretch			= TRUE
      orientation		= HORIZONTAL
      overlay_file		= "Scrollbars/scroll-thumb-horiz.png"
      overlay_stretch	= FALSE
      orientation		= HORIZONTAL


    }

  image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= ACTIVE
      shadow			= IN
      file				= "Scrollbars/slider-horiz.png" 
      border			= { 5, 5, 3, 3}
      stretch			= TRUE
      orientation		= HORIZONTAL
      overlay_file		= "Scrollbars/scroll-thumb-horiz.png"
      overlay_stretch	= FALSE
      orientation		= HORIZONTAL

    }

    image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= PRELIGHT
      file				= "Scrollbars/slider-horiz-prelight.png" 
      border			= { 5, 5, 3, 3}
      stretch			= TRUE
      orientation		= HORIZONTAL
      overlay_file		= "Scrollbars/scroll-thumb-horiz.png"
      overlay_stretch	= FALSE
      orientation		= HORIZONTAL

    }
    image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= INSENSITIVE
      file				= "Scrollbars/slider-horiz-insens.png"
      border			= { 2, 2, 3, 3}
      stretch			= TRUE
      orientation		= HORIZONTAL
      overlay_file		= "Scrollbars/scroll-thumb-horiz.png"
      overlay_stretch	= FALSE
      orientation		= HORIZONTAL

    }

#############x verticals################xx

 image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= NORMAL
      file				= "Scrollbars/slider-vert.png" 
      border			= { 3, 3, 5, 5 }
      stretch			= TRUE
      orientation		= VERTICAL
      overlay_file		= "Scrollbars/scroll-thumb-vert.png"
      overlay_stretch	= FALSE
      orientation		= VERTICAL

    }

   image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= ACTIVE
      shadow			= IN
      file				= "Scrollbars/slider-vert.png" 
      border			= { 3, 3, 5, 5 }
      stretch			= TRUE
      orientation		= VERTICAL
      overlay_file		= "Scrollbars/scroll-thumb-vert.png"
      overlay_stretch	= FALSE
      orientation		= VERTICAL

    }

    image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= PRELIGHT
      file				= "Scrollbars/slider-vert-prelight.png" 
      border			= { 3, 3, 5, 5 }
      stretch			= TRUE
      orientation		= VERTICAL
      overlay_file		= "Scrollbars/scroll-thumb-vert.png"
      overlay_stretch	= FALSE
      orientation		= VERTICAL

    }
    image 
    {
      function			= SLIDER
      recolorable		= TRUE
      state           		= INSENSITIVE
      file				= "Scrollbars/slider-vert-insens.png"
      border			= { 3, 3, 2, 2 }
      stretch			= TRUE
      orientation		= VERTICAL
      overlay_file		= "Scrollbars/scroll-thumb-vert.png"
      overlay_stretch	= FALSE
      orientation		= VERTICAL

    }


###########x END SLIDERS ##################x

########### Steppers ######################
#### UP #######
    image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= NORMAL
      file				= "Scrollbars/stepper-up.png"
      #border			= { 12, 2, 2, 9 }
      stretch			= TRUE
      arrow_direction	= UP
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= PRELIGHT
      file				= "Scrollbars/stepper-up-prelight.png"
      #border			= { 12, 2, 2, 9 }
      stretch			= TRUE
      arrow_direction	= UP
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= ACTIVE
      file				= "Scrollbars/stepper-up-prelight.png"
      #border			= { 12, 2, 2, 9 }
      stretch			= TRUE
      arrow_direction	= UP
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= INSENSITIVE
      file				= "Scrollbars/stepper-up-insens.png"
      #border			= { 12, 2, 2, 9 }
      stretch			= TRUE
      arrow_direction	= UP
    }

 ######### DOWN ############


    image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= NORMAL
      file				= "Scrollbars/stepper-down.png"
      #border			= { 12, 2, 10, 2 }
      stretch			= TRUE
      arrow_direction	= DOWN
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= PRELIGHT
      file				= "Scrollbars/stepper-down-prelight.png"
      #border			= { 12, 2, 10, 2 }
      stretch			= TRUE
      arrow_direction	= DOWN
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= ACTIVE
      file				= "Scrollbars/stepper-down-prelight.png"
      #border			= { 12, 2, 10, 2 }
      stretch			= TRUE
      arrow_direction	= DOWN
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= INSENSITIVE
      file				= "Scrollbars/stepper-down-insens.png"
      #border			= { 12, 2, 10, 2 }
      stretch			= TRUE
      arrow_direction	= DOWN
    }

############ RIGHT ################

    image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= NORMAL
      file				= "Scrollbars/stepper-right.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= RIGHT
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= PRELIGHT
      file				= "Scrollbars/stepper-right-prelight.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= RIGHT
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= ACTIVE
      file				= "Scrollbars/stepper-right-prelight.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= RIGHT
    }
 image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= INSENSITIVE
      file				= "Scrollbars/stepper-right-insens.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= RIGHT
    }

############### LEFT ###################


    image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= NORMAL
      file				= "Scrollbars/stepper-left.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= LEFT
    }
  image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= PRELIGHT
      file				= "Scrollbars/stepper-left-prelight.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= LEFT
    }
  image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= ACTIVE
      file				= "Scrollbars/stepper-left-prelight.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= LEFT
    }
  image 
    {
      function			= STEPPER
      recolorable		= TRUE
      state				= INSENSITIVE
      file				= "Scrollbars/stepper-left-insens.png"
      #border			= { 2, 9, 2, 13 }
      stretch			= TRUE
      arrow_direction	= LEFT
    }

  }
}
class "GtkScrollbar"          style "scrollbar"
